<?php

use EventPortal\Domain\Admin\Handlers\AssignRole;
use EventPortal\Domain\Admin\Handlers\CreateAdmin;
use EventPortal\Domain\Admin\Handlers\UpdateAdmin;
use EventPortal\Domain\Admin\Handlers\UpdateAssignedRole;
use EventPortal\Domain\Admin\Models\Admin;
use EventPortal\Domain\Component\Button;
use EventPortal\Domain\Component\ConfirmButton;
use EventPortal\Domain\Component\Display;
use EventPortal\Domain\Component\Dropdown\Select;
use EventPortal\Domain\Component\Input\Text;
use EventPortal\Domain\Component\Section;
use EventPortal\Domain\Delegate\Handlers\CreateDelegate;
use EventPortal\Domain\Form\Facades\Form;
use EventPortal\Domain\Permission\Models\Role;
use EventPortal\Domain\User\Handlers\CreateUser;
use EventPortal\Domain\User\Handlers\UpdateUser;
use EventPortal\Enums\InertiaMethod;

Form::make('admin.create')
    ->addHandler(CreateUser::class)
    ->addHandler(CreateDelegate::class)
    ->addHandler(CreateAdmin::class)
    ->addHandler(AssignRole::class)
    ->addFields(function () {
        return [
            Section::make('Contact details')->fields([
                Text::make('First name')
                    ->placeholder('Jeff')
                    ->rules(['required']),
                Text::make('Last name')
                    ->placeholder('Smith')
                    ->rules(['required']),
            ]),
            Section::make('Contact details')->fields([
                Text::make('Email')
                    ->placeholder('jeff.smith@example.com')
                    ->rules(['required', 'email', 'unique:users,email']),
            ]),
            Section::make('User role')->fields([
                Select::make('Role')
                    ->name('role_id')
                    ->options(Role::allAsOptions())
                    ->placeholder('Please select a role')
                    ->rules(['required']),
            ]),
        ];
    })
    ->addActions(function () {
        return [
            Button::make('Cancel')
                ->variant('secondary')
                ->method(InertiaMethod::VISIT())
                ->route('admin.user.index'),
        ];
    })
    ->addPrimaryAction(function () {
        return Button::make('Create User')
            ->method(InertiaMethod::POST())
            ->route('admin.user.store');
    });

Form::make('admin.edit')
    ->addHandler(UpdateAssignedRole::class)
    ->addHandler(UpdateAdmin::class)
    ->addHandler(UpdateUser::class)
    ->addFields(function (Admin $admin) {
        return [
            Section::make('Contact details')->fields([
                Text::make('First name')
                    ->placeholder('Jeff')
                    ->rules(['required'])
                    ->scopeTo('user'),
                Text::make('Last name')
                    ->placeholder('Smith')
                    ->rules(['required'])
                    ->scopeTo('user'),
            ]),
            Section::make('Contact details')->fields([
                Text::make('Email')
                    ->placeholder('jeff.smith@example.com')
                    ->rules(['required', 'email'])
                    ->scopeTo('user'),
            ]),
            Section::make('User role')->fields([
                Select::make('Role')
                    ->name('role_id')
                    ->options(Role::allAsOptions())
                    ->value($admin->roleAsOption())
                    ->placeholder('Please select a role')
                    ->rules(['required']),
            ]),
        ];
    })
    ->addActions(function () {
        return [
            Button::make('Cancel')
                ->variant('secondary')
                ->method(InertiaMethod::VISIT())
                ->route('admin.user.index'),
        ];
    })
    ->addPrimaryAction(function (Admin $admin) {
        return Button::make('Update user')
            ->method(InertiaMethod::POST())
            ->route('admin.user.update', ['admin' => $admin->id]);
    });

Form::make('admin.show')
    ->addFields(function () {
        return [
            Section::make('')->fields([
                Display::make('First name')->scopeTo('user'),
                Display::make('Last name')->scopeTo('user'),
            ]),
            Section::make('')->fields([
                Display::make('Email')->scopeTo('user'),
            ]),
            Section::make('')->fields([
                Display::make('Role'),
            ]),
        ];
    })
    ->addAction(function (Admin $admin) {
        if (auth()->user()->id === $admin->user->id) {
            return;
        }

        return ConfirmButton::make('Delete')
            ->content("Are you sure you want to delete {$admin->full_name}?")
            ->variant('danger')
            ->route('admin.user.delete', ['admin' => $admin]);
    })
    ->addAction(function (Admin $admin) {
        return Button::make('Edit')
            ->method(InertiaMethod::VISIT())
            ->route('admin.user.edit', ['admin' => $admin->id]);
    });
