<?php

namespace EventPortal\Domain\SignIn\Concerns;

use Carbon\Carbon;
use EventPortal\Domain\SignIn\Models\SignIn;
use Illuminate\Database\Eloquent\Builder;
use Illuminate\Database\Eloquent\Model;
use Illuminate\Database\Eloquent\Relations\MorphMany;
use Illuminate\Database\Query\JoinClause;

trait SignInAble
{
    public function toggleSignInAt(Model $locationable): void
    {
        if ($this->isSignedInAt($locationable)) {
            $this->signOutFrom($locationable);
            return;
        }

        $this->signInTo($locationable);
    }

    public function isSignedInAt(Model $locationable): bool
    {
        if ($this->signins()->count() < 1) {
            return false;
        }

        return (bool) optional(
            $this->signins()
                ->atLocationable($locationable)
                ->whereNull('signed_out_at')
                ->first(['signed_in_at', 'signed_out_at'])
        )->signedIn;
    }

    public function signInTo(Model $locationable): SignIn
    {
        return SignIn::create([
            'userable_id' => $this->id,
            'userable_type' => self::class,
            'locationable_id' => $locationable->id,
            'locationable_type' => get_class($locationable),
            'signed_in_at' => Carbon::now(),
        ]);
    }

    public function signOutFrom(Model $locationable): SignIn
    {
        return SignIn::updateOrCreate([
            'userable_id' => $this->id,
            'userable_type' => self::class,
            'locationable_id' => $locationable->id,
            'locationable_type' => get_class($locationable),
            'signed_out_at' => null,
        ], ['signed_out_at' => Carbon::now()]);
    }

    public function signIns(): MorphMany
    {
        return $this->morphMany(SignIn::class, 'userable');
    }

    public function scopeWithSignins(Builder $query): Builder
    {
        $table = $this->getTable();
        return $query->leftJoin('sign_ins', static function (JoinClause $query) use ($table): JoinClause {
            return $query->on("{$table}.id", '=', 'sign_ins.userable_id')
                ->where('sign_ins.userable_type', self::class);
        });
    }
}
