<?php

namespace EventPortal\Tests\Unit\Concerns;

use EventPortal\Domain\Event\Models\Event;
use EventPortal\Tests\Support\TestModel;
use EventPortal\Tests\TestCase;
use Illuminate\Foundation\Testing\RefreshDatabase;

class HasTableTest extends TestCase
{
    use RefreshDatabase;

    /** @test **/
    public function can_filter()
    {
        $testModelA = factory(TestModel::class)->create([
            'type' => ['label' => 'Closed', 'value' => 'closed'],
        ]);

        $testModelB = factory(TestModel::class)->create([
            'type' => ['label' => 'Open', 'value' => 'open'],
        ]);

        $actual = TestModel::whereFilter('type', 'open')->get();

        $this->assertCount(1, $actual);
        $this->assertNotContainsModel($testModelA, $actual);
        $this->assertContainsModel($testModelB, $actual);
    }

    /** @test **/
    public function can_get_fields_like()
    {
        $testModelA = factory(Event::class)->create([
            'name' => 'Apple',
        ]);

        $testModelB = factory(Event::class)->create([
            'name' => 'Pear',
        ]);

        $testModelC = factory(Event::class)->create([
            'name' => 'Other Pear',
        ]);

        $actual = Event::fieldsLike(['name'], 'pear')->get();

        $this->assertCount(2, $actual);
        $this->assertContainsModel($testModelB, $actual);
        $this->assertContainsModel($testModelC, $actual);
    }
}
