<?php

namespace EventPortal\Tests\Unit\Models;

use EventPortal\Domain\Admin\Models\Admin;
use EventPortal\Domain\Component\Option;
use EventPortal\Domain\Delegate\Models\Delegate;
use EventPortal\Domain\User\Models\User;
use EventPortal\Seeds\RoleSeeder;
use EventPortal\Tests\Support\Traits\SeedRolesAndPermissions;
use EventPortal\Tests\TestCase;
use Illuminate\Foundation\Testing\DatabaseMigrations;

class AdminTest extends TestCase
{
    use DatabaseMigrations, SeedRolesAndPermissions;

    /** @test **/
    public function returns_true_if_admin_is_compliance(): void
    {
        $admin = factory(Admin::class)->create();

        $admin->assignRole('compliance');

        $this->assertTrue($admin->isCompliance());
    }

    /** @test **/
    public function returns_false_if_admin_is_not_compliance(): void
    {
        $admin = factory(Admin::class)->create();

        $this->assertFalse($admin->isCompliance());
    }

    /** @test **/
    public function can_get_line_manager_as_options()
    {
        $user = factory(User::class)->create(['first_name' => 'Jeff', 'last_name' => 'Jefferson']);
        $admin = factory(Admin::class)->create(['user_id' => $user->id]);
        $admin->assignRole('line-manager');

        $user = factory(User::class)->create(['first_name' => 'Dan', 'last_name' => 'Newens']);
        $admin = factory(Admin::class)->create(['user_id' => $user->id]);
        $admin->assignRole('line-manager');

        $user = factory(User::class)->create(['first_name' => 'Ash', 'last_name' => 'Packwood']);
        $admin = factory(Admin::class)->create(['user_id' => $user->id]);
        $admin->assignRole('compliance');

        $expected = [
            Option::make('Dan Newens')->value(2),
            Option::make('Jeff Jefferson')->value(1),
        ];

        $this->assertEquals($expected, Admin::lineManagerAsOptions());
    }
}
